
//***************************************************
// C++ document adapter for Winmeta plugins
//
// Requires: WINMETA.DLL version 1.0
// (WINMETA.DLL is  2007 Peter Koller, Maison Anglais. All Rights Reserved)
//
// Copyright (C) 2007-2008 Heiko Nitzsche
//
//   This software is provided 'as-is', without any express or implied
//   warranty.  In no event will the author be held liable for any damages
//   arising from the use of this software.
//
//   Permission is granted to anyone to use this software for any purpose,
//   including commercial applications, and to alter it and redistribute it
//   freely, subject to the following restrictions:
//
//   1. The origin of this software must not be misrepresented; you must not
//      claim that you wrote the original software. If you use this software
//      in a product, an acknowledgment in the product documentation would be
//      appreciated but is not required.
//   2. Altered source versions must be plainly marked as such, and must not be
//      misrepresented as being the original software.
//   3. This notice may not be removed or altered from any source distribution.
//
//***************************************************

#ifdef __IBMCPP__
  #pragma strings( readonly )
#endif

#include "os2defs.h"
#include <string.h>
#include "MetaAccessor.hpp"

// ---------------------------------------------------------

MetaAccessor::MetaAccessor() throw (MetaAccessorException)
    : moduleName(NULL),
      moduleHandle(NULLHANDLE),
      fn_IsWinMetafile(NULL),
      fn_InitWinMetafile(NULL),
      fn_PaintWinMetafile(NULL),
      fn_FormatMetafileErrorMsg(NULL)
{
    // load WINMETA.DLL via LIBPATH lookup

    if (! init("WINMETA"))
    {
        throw MetaAccessorException();
    }
}

// ---------------------------------------------------------

MetaAccessor::MetaAccessor(const char * dllPath) throw (MetaAccessorException)
    : moduleName(NULL),
      moduleHandle(NULLHANDLE),
      fn_IsWinMetafile(NULL),
      fn_InitWinMetafile(NULL),
      fn_PaintWinMetafile(NULL),
      fn_FormatMetafileErrorMsg(NULL)
{
    // load WINMETA.DLL via absolute path
    if (! init(dllPath))
    {
        throw MetaAccessorException();
    }
}

// ---------------------------------------------------------

MetaAccessor::~MetaAccessor()
{
    delete [] moduleName;
    moduleName = NULL;

    if (moduleHandle != NULLHANDLE)
    {
        DosFreeModule(moduleHandle);
        moduleHandle = NULLHANDLE;
    }
}

// ---------------------------------------------------------

const char * MetaAccessor::getModuleName() const
{
    return moduleName;
}

// ---------------------------------------------------------

BOOL MetaAccessor::init(const char * dllPath)
{
    if (dllPath == NULL)
    {
        return FALSE;
    }

    // load DLL
    UCHAR  loadError[201] = "";
    APIRET rc             = 0;

    /* load the module */
    rc = DosLoadModule((PSZ)loadError,
                       sizeof(loadError)-1,
                       (PSZ)dllPath,
                       &moduleHandle);
    if (rc == 0)
    {
        const int moduleNameLength = strlen(dllPath);
        moduleName = new char[moduleNameLength+1];
        strcpy(moduleName, dllPath);

        // as _System exported functions
        rc |= DosQueryProcAddr(moduleHandle, 0L, "IsWinMetafile"         , (PFN *) &fn_IsWinMetafile);
        rc |= DosQueryProcAddr(moduleHandle, 0L, "InitWinMetafile"       , (PFN *) &fn_InitWinMetafile);
        rc |= DosQueryProcAddr(moduleHandle, 0L, "PaintWinMetafile"      , (PFN *) &fn_PaintWinMetafile);
        rc |= DosQueryProcAddr(moduleHandle, 0L, "FormatMetafileErrorMsg", (PFN *) &fn_FormatMetafileErrorMsg);

        if (rc)
        {
            delete [] moduleName;
            moduleName = NULL;
            DosFreeModule(moduleHandle);
            moduleHandle = NULLHANDLE;
            return FALSE;
        }
        return TRUE;
    }
    moduleHandle = NULLHANDLE;
    return FALSE;
}

// ---------------------------------------------------------

BOOL MetaAccessor::IsWinMetafile(PCHAR metadata, ULONG metasize) const
{
    return fn_IsWinMetafile(metadata, metasize);
}

// ---------------------------------------------------------

ULONG MetaAccessor::InitWinMetafile(HAB hab, HPS hps, PFNWARNPROC warnproc, PVOID warnprocData, ULONG useOpts) const
{
    return fn_InitWinMetafile(hab, hps, warnproc, warnprocData, useOpts);
}

// ---------------------------------------------------------

ULONG MetaAccessor::PaintWinMetafile(HPS hps, PCHAR metadata, ULONG metasize) const
{
    return fn_PaintWinMetafile(hps, metadata, metasize);
}

// ---------------------------------------------------------

char* MetaAccessor::FormatMetafileErrorMsg(char* buffer, ULONG errcode) const
{
    return fn_FormatMetafileErrorMsg(buffer, errcode);
}


