//***************************************************
// C++ document adapter for Winmeta plugins
//
// Requires: WINMETA.DLL version 1.0
// (WINMETA.DLL is  2007 Peter Koller, Maison Anglais. All Rights Reserved)
//
// Copyright (C) 2007-2008 Heiko Nitzsche
//
//   This software is provided 'as-is', without any express or implied
//   warranty.  In no event will the author be held liable for any damages
//   arising from the use of this software.
//
//   Permission is granted to anyone to use this software for any purpose,
//   including commercial applications, and to alter it and redistribute it
//   freely, subject to the following restrictions:
//
//   1. The origin of this software must not be misrepresented; you must not
//      claim that you wrote the original software. If you use this software
//      in a product, an acknowledgment in the product documentation would be
//      appreciated but is not required.
//   2. Altered source versions must be plainly marked as such, and must not be
//      misrepresented as being the original software.
//   3. This notice may not be removed or altered from any source distribution.
//
//***************************************************

#include "MetaException.hpp"

#include <string.h>
#include <stdio.h>


// constructor
// -----------
MetaException::MetaException(const META_ERR   errorId,
                             const char     * errorMessage,
                             const int        errorLine,
                             const char     * errorFile)
    : line(errorLine),
      id  (errorId)
{
    // alloc memory for the filename and copy the filename to the buffer
    errorFilename = new char[strlen(errorFile) + 1];
    strcpy(errorFilename, errorFile);

    // get the GBM error message
    const int errorMessageLen = strlen(errorMessage);

    // allocate buffer for: "errorMessage: gbmMessage"
    message = new char[errorMessageLen + 1];
    strcpy(message, errorMessage);
}


// copy constructor
// ----------------
MetaException::MetaException( const MetaException & ex )
    : line(ex.line),
      id  (ex.id)
{
    // copy error filename
    errorFilename = new char[strlen(ex.errorFilename) + 1];
    strcpy(errorFilename, ex.errorFilename);

    // copy error message
    message = new char[strlen(ex.message) + 1];
    strcpy(message, ex.message);
}


// destructor
// ----------
MetaException::~MetaException()
{
    delete [] errorFilename;
    delete [] message;
    errorFilename = NULL;
    message       = NULL;
}


// operator =
MetaException & MetaException::operator = ( const MetaException & ex )
{
    if (&ex == this)
    {
        return *this;
    }
    delete [] errorFilename;
    delete [] message;
    errorFilename = NULL;
    message       = NULL;

    // copy error filename
    errorFilename = new char[strlen(ex.errorFilename) + 1];
    strcpy(errorFilename, ex.errorFilename);

    // copy error message
    message = new char[strlen(ex.message) + 1];
    strcpy(message, ex.message);

    line = ex.line;
    id   = ex.id;

    return *this;
}


