#
# Generalised Bitmap Module C++ adapter for GBM plugins,
# C++ document adapter for Winmeta plugins
#
# Copyright (C) 2006-2008 Heiko Nitzsche
#
#   This software is provided 'as-is', without any express or implied
#   warranty.  In no event will the author be held liable for any damages
#   arising from the use of this software.
#
#   Permission is granted to anyone to use this software for any purpose,
#   including commercial applications, and to alter it and redistribute it
#   freely, subject to the following restrictions:
#
#   1. The origin of this software must not be misrepresented; you must not
#      claim that you wrote the original software. If you use this software
#      in a product, an acknowledgment in the product documentation would be
#      appreciated but is not required.
#   2. Altered source versions must be plainly marked as such, and must not be
#      misrepresented as being the original software.
#   3. This notice may not be removed or altered from any source distribution.
#
# This makefile is for Open Watcom C++ on OS/2.
#

# Builds the adapter library to GBM.DLL.
# Builds the adapter library to WINMETA.DLL.

# As GBM.DLL is built multithreaded, all users should also be multithreaded.

# include configuration setting for nmake (except compiler options)
!INCLUDE ..\..\make.opt

# Location of gbm libs and public header files
GBM     = ..\..\gbm
GBMDLG  = ..\..\gbmv_pm\gbmdlg

# Location of winmeta libs and public header files
WINMETA = ..\winmeta

# ------------------
# Configure compiler
# ------------------

#
# Using Open Watcom C++:
#

# Builds gbm objects which are compiled multithreaded
# Therefore all users should also be multithreaded
#CWARNS         = -wx -we
CWARNS         = -w3 -we
CFLAGS         = $(CWARNS) -bt=os2 -zq -zp4 -onatxh -sg -ei -6r -fp6 -fpi87 -bm -mf -xs -xr /DOS2 /DNDEBUG -i. -i$(GBM) -i$(GBMDLG) -i$(WINMETA)
CFLAGS_DBG     = $(CWARNS) -bt=os2 -zq -zp4 -sg -ei -6r -fp6 -fpi87 -bm -mf -xs -xr -i. -i$(GBM) -i$(GBMDLG) -i$(WINMETA) -d2 /DOS2 /DDEBUG
CFLAGS_DLL     = -bd $(CFLAGS)
CFLAGS_DLL_DBG = -bd $(CFLAGS_DBG)

LIBFLAGS       = -q -n -b -c

# For debugging call nmake or wmake with debug=on
!ifdef debug
CFLAGS_DLL     = $(CFLAGS_DLL_DBG)
!endif

# Enable for Pentium profiling (also combined with debug above)
#CFLAGS_DLL     = $(CFLAGS_DLL) -et

#

.SUFFIXES: .cpp .obj

.cpp.obj:
               wpp386 $(CFLAGS_DLL) $*.cpp

#

all:           common.lib

#

common.lib:    ConfigHandler.obj \
               GbmAccessor.obj GbmDialogAccessor.obj GbmException.obj \
               GbmDocument.obj GbmDocumentPage.obj GbmRenderer.obj \
               MetaAccessor.obj MetaDocument.obj MetaException.obj
               -del /N $@ 2> nul
               wlib $(LIBFLAGS) $@ +ConfigHandler.obj \
                                   +GbmAccessor.obj  +GbmDialogAccessor.obj \
                                   +GbmException.obj +GbmDocument.obj \
                                   +GbmDocumentPage.obj +GbmRenderer.obj \
                                   +MetaAccessor.obj  +MetaDocument.obj \
                                   +MetaException.obj


ConfigHandler.obj: ConfigHandler.cpp ConfigHandler.hpp os2defs.h

# GBM files
GbmAccessor.obj:        GbmAccessor.cpp GbmAccessor.hpp os2defs.h $(GBM)\gbm.h

GbmDialogAccessor.obj:  GbmDialogAccessor.cpp GbmDialogAccessor.hpp os2defs.h $(GBMDLG)\gbmdlg.h

GbmException.obj:       GbmException.cpp GbmException.hpp os2defs.h $(GBM)\gbm.h

GbmDocument.obj:        GbmDocument.cpp GbmDocument.hpp os2defs.h $(GBM)\gbm.h

GbmDocumentPage.obj:    GbmDocumentPage.cpp GbmDocumentPage.hpp os2defs.h $(GBM)\gbm.h $(GBM)\gbmmem.h

GbmRenderer.obj:        GbmRenderer.cpp GbmRenderer.hpp os2defs.h \
                          $(GBM)\gbm.h $(GBM)\gbmmem.h $(GBM)\gbmscale.h $(GBM)\gbmmir.h $(GBM)\gbmrect.h

# WINMETA files
MetaAccessor.obj:       MetaAccessor.cpp MetaAccessor.hpp os2defs.h $(WINMETA)\drawwin.h

MetaDocument.obj:       MetaDocument.cpp MetaDocument.hpp os2defs.h $(WINMETA)\drawwin.h

MetaException.obj:      MetaException.cpp MetaException.hpp os2defs.h


# ------------------------
# Build management targets
# ------------------------

clean:
    -del /F /N *.obj *.err 2>nul

clobber:
    -del /F /N *.obj *.lib *.err 2>nul

#

install:

#

exepack:

#

package:


